@@ -18,8 +18,8 @@
 #
 # Program: WorkerLocal.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Mon May 13 18:54:32 2013 +0200
-# Ident:   beeacd63b3b9e6fe986adc9c52feb80ebaf984d8
+# Date:    Tue May 21 18:49:02 2013 +0200
+# Ident:   1f9621d3e8f9730a612900fb3f08e9ebdb14d9e8
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
@@ -27,9 +27,10 @@
 # Timo Benk : 2013-04-28 17:27:31 +0200 : initial checkin
 # Timo Benk : 2013-04-29 18:53:21 +0200 : introducing ncopy
 # Timo Benk : 2013-05-08 09:55:24 +0200 : TARGET_HOST is now visible in ps output
+# Timo Benk : 2013-05-21 18:47:43 +0200 : parameter --async added
 #
 
-package WorkerLocal;
+package NRun::Worker::WorkerLocal;
 
 use strict;
 use warnings;
@@ -39,13 +40,15 @@ use NRun::Worker;
 
 our @ISA = qw(NRun::Worker);
 
-###
-# module specification
-our $MODINFO = {
+BEGIN {
 
-  'MODE' => "local",
-  'DESC' => "execute the script locally, set TARGET_HOST on each execution",
-};
+    NRun::Worker::register ( {
+
+        'MODE' => "local",
+        'DESC' => "execute the script locally, set TARGET_HOST on each execution",
+        'NAME' => "NRun::Worker::WorkerLocal",
+    } );
+}
 
 ###
 # create a new object.
@@ -54,72 +57,83 @@ our $MODINFO = {
 sub new {
 
     my $_pkg = shift;
-    my $_obj = shift;
 
     my $self = {};
     bless $self, $_pkg;
 
-    $self->{MODINFO} = $MODINFO;
     return $self;
 }
 
 ###
-# copy a file to $_host.
+# initialize this worker module.
+#
+# $_cfg - parameter hash where
+# {
+#   'hostname'   - hostname this worker should act on
+#   'dumper'     - dumper object
+#   'logger'     - logger object
+# }
+sub init {
+
+    my $_self = shift;
+    my $_cfg  = shift;
+
+    $_self->SUPER::init($_cfg);
+}
+
+###
+# copy a file to $_self->{hostname}.
 #
-# $_host   - the host the command should be exeuted on
 # $_source - source file to be copied
 # $_target - destination $_source should be copied to
-# <- (
-#      $ret - the return code
-#      $out - command output
-#    )
+# <- the return code
 sub copy {
 
     my $_self   = shift;
-    my $_host   = shift;
     my $_source = shift;
     my $_target = shift;
 
-    return (1, "not implemented");
+    $_self->{logger}->push("not implemented");
+    $_self->{dumper}->push("not implemented");
+    $_self->{logger}->code(1);
+    $_self->{dumper}->code(1);
+
+    return 1;
 }
 
 ###
 # execute the command locally and set environment variable TARGET_HOST
-# to $_host.
+# to $_self->{hostname}.
 #
-# $_host    - the host the command should be exeuted on
 # $_command - the command that should be executed
 # $_args    - arguments that should be supplied to $_command
-# <- (
-#      $ret - the return code
-#      $out - command output
-#    )
+# <- the return code
 sub execute {
 
     my $_self    = shift;
-    my $_host    = shift;
     my $_command = shift;
     my $_args    = shift;
 
-    return _("TARGET_HOST=$_host $_command $_args");
+    my ( $out, $ret ) = $_self->do("TARGET_HOST=$_self->{hostname} $_command $_args");
+    return $ret;
 }
 
 ###
-# delete a file on $_host.
+# delete a file on $_self->{hostname}.
 #
-# $_host - the host the command should be exeuted on
 # $_file - the command that should be executed
-# <- (
-#      $ret - the return code
-#      $out - command output
-#    )
+# <- the return code
 sub delete {
 
     my $_self = shift;
-    my $_host = shift;
     my $_file = shift;
 
-    return (1, "not implemented");
+    $_self->{logger}->push("not implemented");
+    $_self->{dumper}->push("not implemented");
+    $_self->{logger}->code(1);
+    $_self->{dumper}->code(1);
+
+    return 1;
 }
 
 1;
